@@ -6,7 +6,7 @@ use Cwd;
 use base qw(Module::Install::Base);
 use vars qw($VERSION);
 
-$VERSION = '0.28';
+$VERSION = '0.30';
 
 sub githubmeta {
   my $self = shift;
@@ -21,7 +21,7 @@ sub githubmeta {
   my $http_url = $git_url;
   $git_url =~ s![\w\-]+\@([^:]+):!git://$1/!;
   $http_url =~ s![\w\-]+\@([^:]+):!https://$1/!;
-  $http_url =~ s!\.git$!/tree!;
+  $http_url =~ s!\.git$!/!;
   $self->repository( $git_url );
   $self->homepage( $http_url ) unless $self->homepage();
   return 1;
